#include <nexus-user-account-plugin.h>

/**
 * Enunciate-specific C functions.
 */
#ifndef ENUNCIATE_C_UTILITIES
#define ENUNCIATE_C_UTILITIES

/*******************xml utilities************************************/

static int xmlTextReaderAdvanceToNextStartOrEndElement(xmlTextReaderPtr reader) {
  int status = xmlTextReaderRead(reader);
  while (status && xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT && xmlTextReaderNodeType(reader) != XML_READER_TYPE_END_ELEMENT) {
    status = xmlTextReaderRead(reader);
  }
  return status;
}

static int xmlTextReaderSkipElement(xmlTextReaderPtr reader) {
  int status = xmlTextReaderNext(reader);
  while (status && xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT && xmlTextReaderNodeType(reader) != XML_READER_TYPE_END_ELEMENT) {
    status = xmlTextReaderRead(reader);
  }
  return status;
}

static xmlChar *xmlTextReaderReadEntireNodeValue(xmlTextReaderPtr reader) {
  xmlChar *buffer = calloc(1, sizeof(xmlChar));
  const xmlChar *snippet;
  int status;
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ATTRIBUTE) {
    return xmlTextReaderValue(reader);
  }
  else if (xmlTextReaderIsEmptyElement(reader) == 0) {
    status = xmlTextReaderRead(reader);
    while (status && (xmlTextReaderNodeType(reader) == XML_READER_TYPE_TEXT || xmlTextReaderNodeType(reader) == XML_READER_TYPE_CDATA || xmlTextReaderNodeType(reader) == XML_READER_TYPE_ENTITY_REFERENCE)) {
      snippet = xmlTextReaderConstValue(reader);
      buffer = realloc(buffer, (xmlStrlen(buffer) + xmlStrlen(snippet) + 1) * sizeof(xmlChar));
      xmlStrcat(buffer, snippet);
      status = xmlTextReaderRead(reader);
    }
  }
  return buffer;
}

/*******************base 64 utilities************************************/

/*
 * Base64 Translation Table as described in RFC1113.
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 */
static const char cb64[]="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";

/*
 * Base64 Translation Table to decode (created by author)
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 */
static const char cd64[]="|$$$}rstuvwxyz{$$$$$$$>?@ABCDEFGHIJKLMNOPQRSTUVW$$$$$$XYZ[\\]^_`abcdefghijklmnopq";

/*
 * encode 3 8-bit binary bytes as 4 '6-bit' characters
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 *
 * @param in the block to encode
 * @param out the block to encode to
 * @param len the length of the 'in' block.
 */
static void _encode_base64_block(unsigned char in[3], unsigned char out[4], int len) {
  out[0] = cb64[ in[0] >> 2 ];
  out[1] = cb64[ ((in[0] & 0x03) << 4) | ((in[1] & 0xf0) >> 4) ];
  out[2] = (unsigned char) (len > 1 ? cb64[ ((in[1] & 0x0f) << 2) | ((in[2] & 0xc0) >> 6) ] : '=');
  out[3] = (unsigned char) (len > 2 ? cb64[ in[2] & 0x3f ] : '=');
}

/*
 * decode 4 '6-bit' characters into 3 8-bit binary bytes
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 */
static void _decode_base64_block( unsigned char in[4], unsigned char out[3] )
{
    out[ 0 ] = (unsigned char ) (in[0] << 2 | in[1] >> 4);
    out[ 1 ] = (unsigned char ) (in[1] << 4 | in[2] >> 2);
    out[ 2 ] = (unsigned char ) (((in[2] << 6) & 0xc0) | in[3]);
}

/*
 * base64 encode a stream adding padding and line breaks as per spec.
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 *
 * @param instream The stream to encode.
 * @param insize The size of the stream to encode.
 * @return The encoded string.
 */
xmlChar *_encode_base64(unsigned char *instream, int insize) {
  unsigned char in[3];
  unsigned char out[4];
  xmlChar *encoded;
  int i, in_index = 0, out_index = 0, blocklen;

  if (insize == 0) {
    return BAD_CAST "\0";
  }

  encoded = calloc(((insize / 3) * 4) + 10, sizeof(xmlChar));
  while (in_index <= insize) {
    blocklen = 0;
    for (i = 0; i < 3; i++) {
      in[i] = instream[in_index++];
      if (in_index <= insize) {
        blocklen++;
      }
      else {
        in[i] = 0;
      }
    }
    if (blocklen) {
      _encode_base64_block(in, out, blocklen);
      for( i = 0; i < 4; i++ ) {
        encoded[out_index++] = out[i];
      }
    }
  }

  return encoded;
}

/*
 * Decode a base64 encoded stream discarding padding, line breaks and noise
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 *
 * @param invalue The string to decode.
 * @param outsize Holder for the length of the returned data.
 * @return The decoded data.
 */
unsigned char *_decode_base64( const xmlChar *invalue, int *outsize ) {
  xmlChar in[4];
  unsigned char out[3], v;
  int i, in_index = 0, out_index = 0, blocklen;
  unsigned char *outstream;

  if (invalue == NULL) {
    return NULL;
  }

  outstream = calloc(((xmlStrlen(invalue) / 4) * 3) + 1, sizeof(unsigned char));
  while (invalue[in_index] != '\0') {
    for (blocklen = 0, i = 0; i < 4 && invalue[in_index]; i++) {
      v = 0;
      while (invalue[in_index] != '\0' && v == 0) {
        v = (unsigned char) invalue[in_index++];
        v = (unsigned char) ((v < 43 || v > 122) ? 0 : cd64[ v - 43 ]);
        if (v) {
          v = (unsigned char) ((v == '$') ? 0 : v - 61);
        }
      }

      if (invalue[in_index] != '\0') {
        blocklen++;
        if (v) {
          in[i] = (unsigned char) (v - 1);
        }
      }
      else {
        in[i] = 0;
      }
    }

    if (blocklen) {
      _decode_base64_block( in, out );
      for( i = 0; i < blocklen - 1; i++ ) {
        outstream[out_index++] = out[i];
      }
    }
  }

  if (outsize != NULL) {
    *outsize = out_index;
  }

  return outstream;
}

#endif /* ENUNCIATE_C_UTILITIES */

#ifndef ENUNCIATE_OBJC_CLASSES
#define ENUNCIATE_OBJC_CLASSES

/**
 * Protocol defining a JAXB (see https://jaxb.dev.java.net/) type.
 */
@protocol JAXBType

/**
 * Read an XML type from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of the object defining the JAXB type.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader;

/**
 * Initialize the object with an XML reader.
 *
 * @param reader The XML reader from which to initialize the values of this type.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader;

/**
 * Write this instance of a JAXB type to a writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer;

@end /*protocol JAXBType*/


/**
 * Protocol defining a JAXB (see https://jaxb.dev.java.net/) element.
 */
@protocol JAXBElement

/**
 * Read the XML element from an XML reader. It is assumed
 * that the reader is pointing at the start element (be careful
 * that it's not still pointing to the XML document).
 *
 * @param reader The reader.
 * @return An instance of the object defining the JAXB element.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader;

/**
 * Write this instance of a JAXB element to a writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer;

/**
 * Write this instance of a JAXB element to a writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs;

@end /*protocol JAXBElement*/


/**
 * Protocol defining methods for events that occur
 * when reading/parsing XML. Intended for internal
 * use only.
 */
@protocol JAXBReading

/**
 * Method for reading an attribute.
 *
 * @param reader The reader pointing to the attribute.
 * @return Whether the attribute was read.
 */
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader;

/**
 * Method for reading the value of an element.
 *
 * @param reader The reader pointing to the element containing a value.
 * @return Whether the value was read.
 */
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader;

/**
 * Method for reading a child element. If (and only if) the child
 * element was handled, the element in the reader should be
 * "consumed" and the reader will be pointing to the end element.
 *
 * @param reader The reader pointing to the child element.
 * @return Whether the child element was read.
 */
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader;

/**
 * Method for reading an unknown attribute.
 *
 * @param reader The reader pointing to the unknown attribute.
 * @return Whether the attribute was read.
 */
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader;

/**
 * Method for reading an unknown child element. Implementations
 * must be responsible for "consuming" the child element.
 *
 * @param reader The reader pointing to the unknown child element.
 * @return The status of the reader after having consumed the unknown child element.
 */
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader;

@end /*protocol JAXBReading*/

/**
 * Protocol defining methods for events that occur
 * when writing XML. Intended for internal
 * use only.
 */
@protocol JAXBWriting

/**
 * Method for writing the attributes.
 *
 * @param writer The writer.
 */
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer;

/**
 * Method for writing the element value.
 *
 * @param writer The writer.
 */
- (void) writeJAXBValue: (xmlTextWriterPtr) writer;

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer;

@end /*protocol JAXBWriting*/

/**
 * Declaration of the JAXB type, element, events for a base object.
 */
@interface NSObject (JAXB) <JAXBType, JAXBElement, JAXBReading, JAXBWriting>

@end

/**
 * Implementation of the JAXB type, element, events for a base object.
 */
@implementation NSObject (JAXB)

/**
 * Read the XML type from the reader; an instance of NSXMLElement.
 *
 * @param reader The reader.
 * @return An instance of NSXMLElement
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [JAXBBasicXMLNode readXMLType: reader];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  int status, depth;
  if ((self = [self init])) {
    if (xmlTextReaderHasAttributes(reader)) {
      while (xmlTextReaderMoveToNextAttribute(reader)) {
        if ([self readJAXBAttribute: reader] == NO) {
          [self readUnknownJAXBAttribute: reader];
        }
      }

      status = xmlTextReaderMoveToElement(reader);
      if (!status) {
        //panic: unable to return to the element node.
        [NSException raise: @"XMLReadError"
                     format: @"Error moving back to element position from attributes."];
      }
    }

    if ([self readJAXBValue: reader] == NO) {
      //no value handled; attempt to process child elements
      if (xmlTextReaderIsEmptyElement(reader) == 0) {
        depth = xmlTextReaderDepth(reader);//track the depth.
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
        while (xmlTextReaderDepth(reader) > depth) {
          if (status < 1) {
            //panic: XML read error.
            [NSException raise: @"XMLReadError"
                         format: @"Error handling a child element."];
          }
          else if ([self readJAXBChildElement: reader]) {
            status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
          }
          else {
            status = [self readUnknownJAXBChildElement: reader];
          }
        }
      }
    }
  }
  return self;
}

/**
 * Write the XML type value of this object to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [self writeJAXBAttributes: writer];
  [self writeJAXBValue: writer];
  [self writeJAXBChildElements: writer];
}

/**
 * Read the XML element from the reader; an instance of NSXMLElement.
 *
 * @param reader The reader.
 * @return An instance of NSXMLElement
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader
{
  return (id<JAXBElement>) [JAXBBasicXMLNode readXMLType: reader];
}

/**
 * No op; root objects don't have an element name/namespace. Subclasses must override.
 *
 * @param writer The writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  //no-op
}

/**
 * No op; root objects don't have an element name/namespace. Subclasses must override.
 *
 * @param writer The writer.
 * @param writeNs Ignored.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  //no-op
}

/**
 * No-op; base objects do not handle any attributes.
 *
 * @param reader The reader pointing to the attribute.
 * @return NO
 */
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  return NO;
}

/**
 * No-op; base objects do not handle any values.
 *
 * @param reader The reader pointing to the element containing a value.
 * @return NO
 */
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return NO;
}

/**
 * No-op; base objects do not handle any child elements.
 *
 * @param reader The reader pointing to the child element.
 * @return NO
 */
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  return NO;
}

/**
 * No-op; base objects do not handle any attributes.
 *
 * @param reader The reader pointing to the unknown attribute.
 */
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
}

/**
 * Just skips the unknown element; base objects do not handle any child elements.
 *
 * @param reader The reader pointing to the unknown child element.
 * @return The status of the reader after skipping the unknown child element.
 */
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return xmlTextReaderSkipElement(reader);
}

/**
 * No-op; base objects have no attributes.
 *
 * @param writer The writer.
 */
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  //no-op.
}

/**
 * No-op; base objects have no element value.
 *
 * @param writer The writer.
 */
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  //no-op.
}

/**
 * No-op; base objects have no child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  //no-op.
}

@end /*NSObject (JAXB)*/

/**
 * Implementation of the JAXB type, element for an xml element.
 */
@implementation JAXBBasicXMLNode

/**
 * Accessor for the (local) name of the XML node.
 *
 * @return The (local) name of the XML node.
 */
- (NSString *) name
{
  return _name;
}

/**
 * Accessor for the (local) name of the XML node.
 *
 * @param newName The (local) name of the XML node.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * Accessor for the namespace of the XML node.
 *
 * @return The namespace of the XML node.
 */
- (NSString *) ns
{
  return _ns;
}

/**
 * Accessor for the namespace of the XML node.
 *
 * @param newNs The namespace of the XML node.
 */
- (void) setNs: (NSString *) newNs
{
  [newNs retain];
  [_ns release];
  _ns = newNs;
}

/**
 * Accessor for the namespace prefix of the XML node.
 *
 * @return The namespace prefix of the XML node.
 */
- (NSString *) prefix
{
  return _prefix;
}

/**
 * Accessor for the namespace prefix of the XML node.
 *
 * @param newPrefix The namespace prefix of the XML node.
 */
- (void) setPrefix: (NSString *) newPrefix
{
  [newPrefix retain];
  [_prefix release];
  _prefix = newPrefix;
}

/**
 * Accessor for the value of the XML node.
 *
 * @return The value of the XML node.
 */
- (NSString *) value
{
  return _value;
}

/**
 * Accessor for the value of the XML node.
 *
 * @param newValue The value of the XML node.
 */
- (void) setValue: (NSString *) newValue
{
  [newValue retain];
  [_value release];
  _value = newValue;
}

/**
 * Accessor for the child elements of the XML node.
 *
 * @return The child elements of the XML node.
 */
- (NSArray *) childElements
{
  return _childElements;
}

/**
 * Accessor for the child elements of the XML node.
 *
 * @param newValue The child elements of the XML node.
 */
- (void) setChildElements: (NSArray *) newChildElements
{
  [newChildElements retain];
  [_childElements release];
  _childElements = newChildElements;
}

/**
 * Accessor for the attributes of the XML node.
 *
 * @return The attributes of the XML node.
 */
- (NSArray *) attributes
{
  return _attributes;
}

/**
 * Accessor for the attributes of the XML node.
 *
 * @param newAttributes The attributes of the XML node.
 */
- (void) setAttributes: (NSArray *) newAttributes
{
  [newAttributes retain];
  [_attributes release];
  _attributes = newAttributes;
}

- (void) dealloc {
  [self setName: nil];
  [self setNs: nil];
  [self setPrefix: nil];
  [self setValue: nil];
  [self setChildElements: nil];
  [self setAttributes: nil];
  [super dealloc];
}
@end /*implementation JAXBBasicXMLNode*/

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface JAXBBasicXMLNode (JAXB) <JAXBType, JAXBElement>

@end /*interface JAXBBasicXMLNode (JAXB)*/

@implementation JAXBBasicXMLNode (JAXB)

/**
 * Read the XML type from the reader; an instance of JAXBBasicXMLNode.
 *
 * @param reader The reader.
 * @return An instance of JAXBBasicXMLNode
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  JAXBBasicXMLNode *node = [[JAXBBasicXMLNode alloc] init];
  NS_DURING
  {
    [node initWithReader: reader];
  }
  NS_HANDLER
  {
    [node dealloc];
    node = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [node autorelease];
  return node;
}

/**
 * Read an XML type from an XML reader into an existing instance of JAXBBasicXMLNode.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  int status, depth;
  JAXBBasicXMLNode *child;
  xmlChar *value = NULL;
  const xmlChar *text;
  NSMutableArray *children;

  if ((self = [self init])) {
    depth = xmlTextReaderDepth(reader);
    [self setName: [NSString stringWithUTF8String: (const char *) xmlTextReaderLocalName(reader)]];
    [self setNs: [NSString stringWithUTF8String: (const char *) xmlTextReaderNamespaceUri(reader)]];
    [self setPrefix: [NSString stringWithUTF8String: (const char *)xmlTextReaderPrefix(reader)]];

    if (xmlTextReaderHasAttributes(reader)) {
      child = nil;
      children = [[NSMutableArray alloc] init];
      while (xmlTextReaderMoveToNextAttribute(reader)) {
        child = [[JAXBBasicXMLNode alloc] init];
        [child setName: [NSString stringWithUTF8String: (const char *) xmlTextReaderLocalName(reader)]];
        [child setNs: [NSString stringWithUTF8String: (const char *)xmlTextReaderNamespaceUri(reader)]];
        [child setPrefix: [NSString stringWithUTF8String: (const char *) xmlTextReaderPrefix(reader)]];
        [child setValue: [NSString stringWithUTF8String: (const char *) xmlTextReaderValue(reader)]];
        [children addObject: child];
      }
      [self setAttributes: children];

      status = xmlTextReaderMoveToElement(reader);
      if (status < 1) {
        //panic: unable to return to the element node.
        [NSException raise: @"XMLReadError"
                     format: @"Error moving to element from attributes."];
      }
    }

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
      children = [[NSMutableArray alloc] init];
      status = xmlTextReaderRead(reader);
      while (status == 1 && xmlTextReaderDepth(reader) > depth) {
        switch (xmlTextReaderNodeType(reader)) {
          case XML_READER_TYPE_ELEMENT:
            child = (JAXBBasicXMLNode *) [JAXBBasicXMLNode readXMLType: reader];
            [children addObject: child];
            break;
          case XML_READER_TYPE_TEXT:
          case XML_READER_TYPE_CDATA:
            text = xmlTextReaderConstValue(reader);
            value = xmlStrncat(value, text, xmlStrlen(text));
            break;
          default:
            //skip anything else.
            break;
        }

        status = xmlTextReaderRead(reader);
      }

      if (status < 1) {
        //panic: xml read error
        [NSException raise: @"XMLReadError"
                     format: @"Error reading child elements."];
      }

      if ([children count] > 0) {
        [self setChildElements: children];
      }

      if (value != NULL) {
        [self setValue: [NSString stringWithUTF8String: (const char *) value]];
      }

    }
  }

  return self;
}

/**
 * Read the XML element from the reader; an instance of NSXMLElement.
 *
 * @param reader The reader.
 * @return An instance of NSXMLElement
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader
{
  return (id<JAXBElement>) [JAXBBasicXMLNode readXMLType: reader];
}

/**
 * Write the basic node to an xml writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  int status;
  NSEnumerator *enumerator;
  JAXBBasicXMLNode *child;
  xmlChar *childns, *childname, *childprefix, *childvalue;

  status = xmlTextWriterStartElementNS(writer, _prefix ? BAD_CAST [_prefix UTF8String] : NULL, _name ? BAD_CAST [_name UTF8String] : NULL, _ns ? BAD_CAST [_ns UTF8String] : NULL);
  if (status < 0) {
    childns = BAD_CAST "";
    if (_ns) {
      childns = BAD_CAST [_ns UTF8String];
    }

    childname = BAD_CAST "";
    if (_name) {
      childname = BAD_CAST [_name UTF8String];
    }

    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {%s}%s for JAXBBasicXMLNode.", childns, childname];
  }

  if (_attributes) {
    enumerator = [_attributes objectEnumerator];
    while ( (child = (JAXBBasicXMLNode *)[enumerator nextObject]) ) {
      childns = NULL;
      if ([child ns]) {
        childns = BAD_CAST [[child ns] UTF8String];
      }

      childprefix = NULL;
      if ([child prefix]) {
        childprefix = BAD_CAST [[child prefix] UTF8String];
      }

      childname = NULL;
      if ([child name]) {
        childname = BAD_CAST [[child name] UTF8String];
      }

      childvalue = NULL;
      if ([child value]) {
        childvalue = BAD_CAST [[child value] UTF8String];
      }

      status = xmlTextWriterWriteAttributeNS(writer, childprefix, childname, childns, childvalue);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing attribute {%s}%s for JAXBBasicXMLNode.", childns, childname];
      }
    }
  }

  if (_value) {
    status = xmlTextWriterWriteString(writer, BAD_CAST [_value UTF8String]);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing value of JAXBBasicXMLNode."];
    }
  }

  if (_childElements) {
    enumerator = [_childElements objectEnumerator];
    while ( (child = [enumerator nextObject]) ) {
      [child writeXMLType: writer];
    }
  }

  status = xmlTextWriterEndElement(writer);
  if (status < 0) {
    childns = BAD_CAST "";
    if (_ns) {
      childns = BAD_CAST [_ns UTF8String];
    }

    childname = BAD_CAST "";
    if (_name) {
      childname = BAD_CAST [_name UTF8String];
    }

    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {%s}%s for JAXBBasicXMLNode.", childns, childname];
  }
}

/**
 * Writes this node to a writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLType: writer];
}

/**
 * Writes this node to a writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  [self writeXMLType: writer];
}

@end /* implementation JAXBBasicXMLNode (JAXB) */

/**
 * Declaration of the JAXB type for a string.
 */
@interface NSString (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a string.
 */
@implementation NSString (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSString that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing string cannot be modified."];
  return nil;
}

/**
 * Write the NSString to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [self UTF8String]);
}

@end /*NSString (JAXBType)*/



/**
 * Declaration of the JAXB type for a big number.
 */
@interface NSNumber (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a big number.
 */
@implementation NSNumber (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSNumber that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSNumber numberWithLongLong: [[NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)] longLongValue]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing number cannot be modified."];
  return nil;
}

/**
 * Write the NSNumber to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [[self description] UTF8String]);
}

@end /*NSNumber (JAXBType)*/



/**
 * Declaration of the JAXB type for a big number.
 */
@interface NSDecimalNumber (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a big number.
 */
@implementation NSDecimalNumber (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSDecimalNumber that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSDecimalNumber decimalNumberWithString: [NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing decimal number cannot be modified."];
  return nil;
}

/**
 * Write the NSDecimalNumber to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [[self description] UTF8String]);
}

@end /*NSDecimalNumber (JAXBType)*/



/**
 * Declaration of the JAXB type for a url.
 */
@interface NSURL (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a url.
 */
@implementation NSURL (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSURL that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSURL URLWithString: [NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing url cannot be modified."];
  return nil;
}

/**
 * Write the NSURL to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [[self absoluteString] UTF8String]);
}

@end /*NSURL (JAXBType)*/



/**
 * Declaration of the JAXB type for binary data.
 */
@interface NSData (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a binary data.
 */
@implementation NSData (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSData that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  xmlChar *base64data = xmlTextReaderReadEntireNodeValue(reader);
  int len;
  unsigned char *data = _decode_base64(base64data, &len);
  NSData *wrappedData = [NSData dataWithBytesNoCopy: data length: len];
  free(base64data);
  return wrappedData;
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing NSData cannot be modified."];
  return nil;
}

/**
 * Write the NSData to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlChar *out = _encode_base64((unsigned char *)[self bytes], [self length]);
  xmlTextWriterWriteString(writer, out);
  free(out);
}

@end /*NSData (JAXBType)*/



/**
 * Declaration of the JAXB type for a big number.
 */
@interface NSDate (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a big number.
 */
@implementation NSDate (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSDate that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  xmlChar *timevalue = xmlTextReaderReadEntireNodeValue(reader);
  NSInteger year = 0;
  NSUInteger month = 1, day = 1, hour = 0, minute = 0, second = 0;
  BOOL skip_time = NO;
  int index = 0, token_index = 0, len = xmlStrlen(timevalue), offset_hour = 0, offset_minute = 0;
  char token[len];

  if (len > (index + 5) && timevalue[index + 4] == '-') {
    //assume we're at yyyy-MM-dd
    token_index = 0;
    while (index < len && timevalue[index] != '-') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 4) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid year: %s", timevalue, token];
    }
    year = atoi(token);
    index++;

    //go to next '-' character.
    token_index = 0;
    while (index < len && timevalue[index] != '-') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid month: %s", timevalue, token];
    }
    month = atoi(token);
    index++;

    //go to 'T', 'Z', '+', or '-' character.
    token_index = 0;
    while (index < len && timevalue[index] != 'T' && timevalue[index] != 'Z' && timevalue[index] != '-' && timevalue[index] != '+') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid day of month: %s", timevalue, token];
    }
    day = atoi(token);
    if (timevalue[index] != 'T') {
      skip_time = YES;
    }
    if (timevalue[index] != '-') {
      index++;
    }
  }

  if (skip_time == NO || (len > (index + 3) && timevalue[index + 2] == ':')) {
    //assume we're at HH:mm:ss

    //go to ':' character.
    token_index = 0;
    while (index < len && timevalue[index] != ':') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid hour: %s", timevalue, token];
    }
    hour = atoi(token);
    index++;

    //go to ':' character.
    token_index = 0;
    while (index < len && timevalue[index] != ':') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid minute: %s", timevalue, token];
    }
    minute = atoi(token);
    index++;

    //go to '+' or '-' or 'Z' character.
    token_index = 0;
    while (index < len && timevalue[index] != '+' && timevalue[index] != '-' && timevalue[index] != 'Z') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index == 0) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid seconds: %s", timevalue, token];
    }
    second = (NSUInteger) atof(token);
    if (timevalue[index] != '-') {
      index++;
    }
  }

  //go to ':' character.
  token_index = 0;
  while (index < len && timevalue[index] != ':') {
    token[token_index++] = timevalue[index++];
  }
  token[token_index] = '\0';
  offset_hour += atoi(token);
  index++;

  //go to end.
  token_index = 0;
  while (index < len) {
    token[token_index++] = timevalue[index++];
  }
  token[token_index] = '\0';
  offset_minute += atoi(token);

  //YYYY-MM-DD HH:MM:SS -HHHMM
  free(timevalue);
  return [NSDate dateWithString: [NSString stringWithFormat: @"%04i-%02i-%02i %02i:%02i:%02i %+03i%02i", year, month, day, hour, minute, second, offset_hour, offset_minute]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing date cannot be modified."];
  return nil;
}

/**
 * Write the NSDate to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  NSDateFormatter *formatter = [[NSDateFormatter alloc] initWithDateFormat: @"%Y-%m-%dT%H:%M:%S %z" allowNaturalLanguage: NO];
  xmlChar *timevalue = BAD_CAST [[formatter stringForObjectValue: self] UTF8String];
  timevalue[19] = timevalue[20];
  timevalue[20] = timevalue[21];
  timevalue[21] = timevalue[22];
  timevalue[22] = ':';
  xmlTextWriterWriteString(writer, timevalue);
  [formatter release];
}
@end /*NSDate (JAXBType)*/

#endif /* ENUNCIATE_OBJC_CLASSES */

#ifndef ENUNCIATE_XML_OBJC_PRIMITIVE_FUNCTIONS
#define ENUNCIATE_XML_OBJC_PRIMITIVE_FUNCTIONS

/*******************boolean************************************/

/**
 * Read a boolean value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return YES if "true" was read. NO otherwise.
 */
static BOOL *xmlTextReaderReadBooleanType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  BOOL *value = malloc(sizeof(BOOL));
  *value = (xmlStrcmp(BAD_CAST "true", nodeValue) == 0) ? YES : NO;
  free(nodeValue);
  return value;
}

/**
 * Write a boolean value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteBooleanType(xmlTextWriterPtr writer, BOOL *value) {
  if (*value) {
    return xmlTextWriterWriteString(writer, BAD_CAST "false");
  }
  else {
    return xmlTextWriterWriteString(writer, BAD_CAST "true");
  }
}

/*******************byte************************************/

/**
 * Read a byte value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the byte.
 */
static unsigned char *xmlTextReaderReadByteType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  unsigned char *value = malloc(sizeof(unsigned char));
  *value = (unsigned char) atoi((char *) nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a byte value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteByteType(xmlTextWriterPtr writer, unsigned char *value) {
  return xmlTextWriterWriteFormatString(writer, "%i", *value);
}

/*******************double************************************/

/**
 * Read a double value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the double.
 */
static double *xmlTextReaderReadDoubleType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  double *value = malloc(sizeof(double));
  *value = atof((char *) nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a double value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteDoubleType(xmlTextWriterPtr writer, double *value) {
  return xmlTextWriterWriteFormatString(writer, "%f", *value);
}

/*******************float************************************/

/**
 * Read a float value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the float.
 */
static float *xmlTextReaderReadFloatType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  float *value = malloc(sizeof(float));
  *value = atof((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a float value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteFloatType(xmlTextWriterPtr writer, float *value) {
  return xmlTextWriterWriteFormatString(writer, "%f", *value);
}

/*******************int************************************/

/**
 * Read a int value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @param value The value to be written.
 * @return the int.
 */
static int *xmlTextReaderReadIntType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  int *value = malloc(sizeof(int));
  *value = atoi((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a int value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteIntType(xmlTextWriterPtr writer, int *value) {
  return xmlTextWriterWriteFormatString(writer, "%i", *value);
}

/*******************long************************************/

/**
 * Read a long value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the long.
 */
static long *xmlTextReaderReadLongType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  long *value = malloc(sizeof(long));
  *value = atol((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a long value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteLongType(xmlTextWriterPtr writer, long *value) {
  return xmlTextWriterWriteFormatString(writer, "%ld", *value);
}

/*******************short************************************/

/**
 * Read a short value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the short.
 */
static short *xmlTextReaderReadShortType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  short *value = malloc(sizeof(short));
  *value = atoi((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a short value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteShortType(xmlTextWriterPtr writer, short *value) {
  return xmlTextWriterWriteFormatString(writer, "%hi", *value);
}

/*******************char************************************/

/**
 * Read a character value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the character.
 */
static xmlChar *xmlTextReaderReadCharacterType(xmlTextReaderPtr reader) {
  return xmlTextReaderReadEntireNodeValue(reader);
}

/**
 * Write a character value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteCharacterType(xmlTextWriterPtr writer, xmlChar *value) {
  return xmlTextWriterWriteString(writer, value);
}

#endif /* ENUNCIATE_XML_OBJC_PRIMITIVE_FUNCTIONS */

#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO

/**
 * (no documentation provided)
 */
- (NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO *) userAccount
{
  return _userAccount;
}

/**
 * (no documentation provided)
 */
- (void) setUserAccount: (NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO *) newUserAccount
{
  [newUserAccount retain];
  [_userAccount release];
  _userAccount = newUserAccount;
}

/**
 * (no documentation provided)
 */
- (NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO *) captcha
{
  return _captcha;
}

/**
 * (no documentation provided)
 */
- (void) setCaptcha: (NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO *) newCaptcha
{
  [newCaptcha retain];
  [_captcha release];
  _captcha = newCaptcha;
}

- (void) dealloc
{
  [self setUserAccount: nil];
  [self setCaptcha: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO *) [NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO = [[NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO from an XML reader. The element to be read is
 * "signUpRequest".
 *
 * @param reader The XML reader.
 * @return The NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO *_signUpRequestDTO = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element signUpRequest."];
    }
  }

  if (xmlStrcmp(BAD_CAST "signUpRequest", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}signUpRequest.");
#endif
    _signUpRequestDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO *)[NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}signUpRequest.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO. Expected element signUpRequest. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO. Expected element signUpRequest. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _signUpRequestDTO;
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO to XML under element name "signUpRequest".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _signUpRequestDTO The SignUpRequestDTO to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "signUpRequest", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}signUpRequest. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}signUpRequestDTO for root element {}signUpRequest...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}signUpRequestDTO for root element {}signUpRequest...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}signUpRequest. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "userAccount", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}userAccount of type {}signUpUserAccount.");
#endif
    __child = [NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}userAccount of type {}signUpUserAccount.");
#endif

    [self setUserAccount: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "captcha", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}captcha of type {}captcha.");
#endif
    __child = [NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}captcha of type {}captcha.");
#endif

    [self setCaptcha: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self userAccount]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userAccount", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}userAccount."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}userAccount...");
#endif
    [[self userAccount] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}userAccount...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}userAccount."];
    }
  }
  if ([self captcha]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "captcha", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}captcha."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}captcha...");
#endif
    [[self captcha] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}captcha...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}captcha."];
    }
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0SignUpRequestDTO_M */
#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO

/**
 * (no documentation provided)
 */
- (NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO *) [NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO = [[NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO from an XML reader. The element to be read is
 * "signUpUserAccountRequest".
 *
 * @param reader The XML reader.
 * @return The NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO *_signUpUserAccountWrapperDTO = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element signUpUserAccountRequest."];
    }
  }

  if (xmlStrcmp(BAD_CAST "signUpUserAccountRequest", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}signUpUserAccountRequest.");
#endif
    _signUpUserAccountWrapperDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO *)[NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}signUpUserAccountRequest.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO. Expected element signUpUserAccountRequest. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO. Expected element signUpUserAccountRequest. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _signUpUserAccountWrapperDTO;
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO to XML under element name "signUpUserAccountRequest".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _signUpUserAccountWrapperDTO The SignUpUserAccountWrapperDTO to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "signUpUserAccountRequest", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}signUpUserAccountRequest. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}signUpUserAccountWrapperDTO for root element {}signUpUserAccountRequest...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}signUpUserAccountWrapperDTO for root element {}signUpUserAccountRequest...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}signUpUserAccountRequest. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}signUpUserAccount.");
#endif
    __child = [NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}signUpUserAccount.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountWrapperDTO_M */
#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO

/**
 * (no documentation provided)
 */
- (NSArray *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO *) [NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO = [[NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO from an XML reader. The element to be read is
 * "userAccountDefaultRolesResponse".
 *
 * @param reader The XML reader.
 * @return The NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO *_userAccountDefaultRolesResponseDTO = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element userAccountDefaultRolesResponse."];
    }
  }

  if (xmlStrcmp(BAD_CAST "userAccountDefaultRolesResponse", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}userAccountDefaultRolesResponse.");
#endif
    _userAccountDefaultRolesResponseDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO *)[NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}userAccountDefaultRolesResponse.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO. Expected element userAccountDefaultRolesResponse. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO. Expected element userAccountDefaultRolesResponse. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _userAccountDefaultRolesResponseDTO;
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO to XML under element name "userAccountDefaultRolesResponse".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _userAccountDefaultRolesResponseDTO The UserAccountDefaultRolesResponseDTO to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userAccountDefaultRolesResponse", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}userAccountDefaultRolesResponse. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}userAccountDefaultRolesResponseDTO for root element {}userAccountDefaultRolesResponse...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}userAccountDefaultRolesResponseDTO for root element {}userAccountDefaultRolesResponse...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}userAccountDefaultRolesResponse. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}data."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}data...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}data...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}data."];
      }
    } //end item iterator.
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesResponseDTO_M */
#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO

/**
 * (no documentation provided)
 */
- (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO *) [NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO = [[NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO from an XML reader. The element to be read is
 * "userAccountStatusRequest".
 *
 * @param reader The XML reader.
 * @return The NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO *_userAccountStatusRequestDTO = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element userAccountStatusRequest."];
    }
  }

  if (xmlStrcmp(BAD_CAST "userAccountStatusRequest", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}userAccountStatusRequest.");
#endif
    _userAccountStatusRequestDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO *)[NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}userAccountStatusRequest.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO. Expected element userAccountStatusRequest. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO. Expected element userAccountStatusRequest. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _userAccountStatusRequestDTO;
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO to XML under element name "userAccountStatusRequest".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _userAccountStatusRequestDTO The UserAccountStatusRequestDTO to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userAccountStatusRequest", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}userAccountStatusRequest. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}userAccountStatusRequestDTO for root element {}userAccountStatusRequest...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}userAccountStatusRequestDTO for root element {}userAccountStatusRequest...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}userAccountStatusRequest. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}userAccountStatus.");
#endif
    __child = [NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}userAccountStatus.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusRequestDTO_M */
#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount

/**
 * (no documentation provided)
 */
- (NSString *) lastName
{
  return _lastName;
}

/**
 * (no documentation provided)
 */
- (void) setLastName: (NSString *) newLastName
{
  [newLastName retain];
  [_lastName release];
  _lastName = newLastName;
}

/**
 * (no documentation provided)
 */
- (NSString *) firstName
{
  return _firstName;
}

/**
 * (no documentation provided)
 */
- (void) setFirstName: (NSString *) newFirstName
{
  [newFirstName retain];
  [_firstName release];
  _firstName = newFirstName;
}

/**
 * (no documentation provided)
 */
- (NSString *) userId
{
  return _userId;
}

/**
 * (no documentation provided)
 */
- (void) setUserId: (NSString *) newUserId
{
  [newUserId retain];
  [_userId release];
  _userId = newUserId;
}

/**
 * (no documentation provided)
 */
- (NSString *) email
{
  return _email;
}

/**
 * (no documentation provided)
 */
- (void) setEmail: (NSString *) newEmail
{
  [newEmail retain];
  [_email release];
  _email = newEmail;
}

- (void) dealloc
{
  [self setLastName: nil];
  [self setFirstName: nil];
  [self setUserId: nil];
  [self setEmail: nil];
  [super dealloc];
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount *_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccount = [[NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccount initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccount dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccount = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccount autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccount;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "lastName", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}lastName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}lastName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLastName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "firstName", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}firstName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}firstName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFirstName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "userId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}userId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}userId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUserId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "email", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}email of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}email of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setEmail: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self lastName]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "lastName", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}lastName."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}lastName...");
#endif
    [[self lastName] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}lastName...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}lastName."];
    }
  }
  if ([self firstName]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "firstName", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}firstName."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}firstName...");
#endif
    [[self firstName] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}firstName...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}firstName."];
    }
  }
  if ([self userId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}userId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}userId...");
#endif
    [[self userId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}userId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}userId."];
    }
  }
  if ([self email]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "email", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}email."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}email...");
#endif
    [[self email] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}email...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}email."];
    }
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccount_M */
#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO

/**
 * (no documentation provided)
 */
- (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO *) [NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO = [[NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO from an XML reader. The element to be read is
 * "userAccountStatusResponse".
 *
 * @param reader The XML reader.
 * @return The NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO *_userAccountStatusResponseDTO = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element userAccountStatusResponse."];
    }
  }

  if (xmlStrcmp(BAD_CAST "userAccountStatusResponse", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}userAccountStatusResponse.");
#endif
    _userAccountStatusResponseDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO *)[NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}userAccountStatusResponse.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO. Expected element userAccountStatusResponse. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO. Expected element userAccountStatusResponse. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _userAccountStatusResponseDTO;
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO to XML under element name "userAccountStatusResponse".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _userAccountStatusResponseDTO The UserAccountStatusResponseDTO to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userAccountStatusResponse", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}userAccountStatusResponse. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}userAccountStatusResponseDTO for root element {}userAccountStatusResponse...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}userAccountStatusResponseDTO for root element {}userAccountStatusResponse...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}userAccountStatusResponse. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}userAccountStatus.");
#endif
    __child = [NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}userAccountStatus.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusResponseDTO_M */
#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO

/**
 * (no documentation provided)
 */
- (BOOL) enabled
{
  return _enabled;
}

/**
 * (no documentation provided)
 */
- (void) setEnabled: (BOOL) newEnabled
{
  _enabled = newEnabled;
}

- (void) dealloc
{
  [super dealloc];
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO = [[NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "enabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "enabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}enabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}enabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_enabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}enabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}enabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}enabled."];
    }
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountStatusDTO_M */
#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO

/**
 * (no documentation provided)
 */
- (NSArray *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO *) [NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO = [[NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO from an XML reader. The element to be read is
 * "userAccountDefaultRolesRequest".
 *
 * @param reader The XML reader.
 * @return The NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO *_userAccountDefaultRolesRequestDTO = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element userAccountDefaultRolesRequest."];
    }
  }

  if (xmlStrcmp(BAD_CAST "userAccountDefaultRolesRequest", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}userAccountDefaultRolesRequest.");
#endif
    _userAccountDefaultRolesRequestDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO *)[NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}userAccountDefaultRolesRequest.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO. Expected element userAccountDefaultRolesRequest. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO. Expected element userAccountDefaultRolesRequest. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _userAccountDefaultRolesRequestDTO;
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO to XML under element name "userAccountDefaultRolesRequest".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _userAccountDefaultRolesRequestDTO The UserAccountDefaultRolesRequestDTO to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userAccountDefaultRolesRequest", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}userAccountDefaultRolesRequest. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}userAccountDefaultRolesRequestDTO for root element {}userAccountDefaultRolesRequest...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}userAccountDefaultRolesRequestDTO for root element {}userAccountDefaultRolesRequest...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}userAccountDefaultRolesRequest. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}data."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}data...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}data...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}data."];
      }
    } //end item iterator.
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0UserAccountDefaultRolesRequestDTO_M */
#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO

/**
 * (no documentation provided)
 */
- (NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO *) [NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO = [[NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO from an XML reader. The element to be read is
 * "captchaResponse".
 *
 * @param reader The XML reader.
 * @return The NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO *_captchaResponseDTO = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element captchaResponse."];
    }
  }

  if (xmlStrcmp(BAD_CAST "captchaResponse", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}captchaResponse.");
#endif
    _captchaResponseDTO = (NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO *)[NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}captchaResponse.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO. Expected element captchaResponse. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO. Expected element captchaResponse. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _captchaResponseDTO;
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO to XML under element name "captchaResponse".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _captchaResponseDTO The CaptchaResponseDTO to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "captchaResponse", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}captchaResponse. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}captchaResponseDTO for root element {}captchaResponse...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}captchaResponseDTO for root element {}captchaResponse...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}captchaResponse. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}captcha.");
#endif
    __child = [NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}captcha.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaResponseDTO_M */
#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO

/**
 * (no documentation provided)
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * (no documentation provided)
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * (no documentation provided)
 */
- (NSString *) key
{
  return _key;
}

/**
 * (no documentation provided)
 */
- (void) setKey: (NSString *) newKey
{
  [newKey retain];
  [_key release];
  _key = newKey;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setKey: nil];
  [super dealloc];
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO = [[NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "key", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}key of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}key of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setKey: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self key]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "key", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}key."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}key...");
#endif
    [[self key] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}key...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}key."];
    }
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0CaptchaDTO_M */
#ifndef DEF_NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO_M
#define DEF_NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO

/**
 * (no documentation provided)
 */
- (NSString *) password
{
  return _password;
}

/**
 * (no documentation provided)
 */
- (void) setPassword: (NSString *) newPassword
{
  [newPassword retain];
  [_password release];
  _password = newPassword;
}

/**
 * (no documentation provided)
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * (no documentation provided)
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * (no documentation provided)
 */
- (NSString *) oldPassword
{
  return _oldPassword;
}

/**
 * (no documentation provided)
 */
- (void) setOldPassword: (NSString *) newOldPassword
{
  [newOldPassword retain];
  [_oldPassword release];
  _oldPassword = newOldPassword;
}

- (void) dealloc
{
  [self setPassword: nil];
  [self setResourceURI: nil];
  [self setOldPassword: nil];
  [super dealloc];
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO (JAXB)

/**
 * Read an instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO *_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO = [[NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO dealloc];
    _nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO autorelease];
  return _nEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO;
}

/**
 * Initialize this instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "password", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setPassword: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "oldPassword", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}oldPassword of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}oldPassword of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setOldPassword: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self password]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "password", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}password."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}password...");
#endif
    [[self password] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}password...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}password."];
    }
  }
  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self oldPassword]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "oldPassword", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}oldPassword."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}oldPassword...");
#endif
    [[self oldPassword] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}oldPassword...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}oldPassword."];
    }
  }
}
@end /* implementation NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO (JAXB) */

#endif /* DEF_NEXUS_USER_ACCOUNT_PLUGINNS0SignUpUserAccountDTO_M */
