/*
 * Copyright (c) 2008-2012 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
Sonatype.repoServer.SmartProxyCertificateUtils = {
  showAddCertificateWindow : function(label, rec) {
    var window = new Ext.Window({
      title : label,
      closable : true,
      autoWidth : false,
      width : 600,
      autoHeight : true,
      modal : true,
      constrain : true,
      resizable : false,
      draggable : false,
      scope : this,
      items : [
        {
          xtype : 'form',
          id : 'sp_publicKeyForm',
          name : 'publicKeyForm',
          labelWidth : 125,
          frame : true,
          defaultType : 'textfield',
          monitorValid : true,
          items : [
            {
              xtype : 'hidden',
              name : 'id'
            },
            {
              xtype : 'textarea',
              fieldLabel : 'Certificate',
              hideLabel : true,
              name : 'certificate',
              helpText : 'A certificate to trust (PEM format). Allow the remote Nexus instance with this certificate to access smart proxy services.',
              height : 200,
              itemCls : 'required-field',
              allowBlank : false,
              wordWrap : false,
              anchor : Sonatype.view.FIELDSET_OFFSET
            },
            {
              xtype : 'label',
              text : 'Details',
              hideLabel : true,
              style : 'text-decoration: underline; color: blue; cursor: pointer; padding-left: 520px;',
              listeners : {
                render : {
                  fn : function(component) {
                    var handler = function() {
                      var pemField = Ext.getCmp('sp_publicKeyForm').getForm().findField('certificate');

                      if (rec && rec.data.certificate.detail && rec.data.certificate.pem == pemField.getValue()) {
                        this.showCertificateDetailWindow(rec.data.certificate.detail);
                      }
                      else {
                        Ext.Ajax.request({
                          url : Sonatype.config.servicePath + '/smartproxy/certificate-detail',
                          method : 'PUT',
                          jsonData : {
                            pem : Ext.getCmp('sp_publicKeyForm').getForm().findField('certificate').getValue()
                          },
                          success : function(resp) {
                            this.showCertificateDetailWindow(resp.responseText);
                          },
                          failure : function(resp) {
                            if (resp.status == 400) {
                              var json = Ext.decode(resp.responseText);
                              if (json && json.errors && json.errors[0] && json.errors[0].id === 'certificate') {
                                Sonatype.MessageBox.hide();
                                Ext.getCmp('sp_publicKeyForm').getForm().findField('certificate').markInvalid(json.errors[0].msg);
                              }
                            }
                          },
                          scope : this
                        });
                      }
                    }
                    component.getEl().on('click', handler.createDelegate(this));
                  },
                  scope: this
                }
              }
            },
            {
              fieldLabel : 'Description',
              xtype : 'textfield',
              name : 'description',
              itemCls : 'required-field',
              allowBlank : false,
              // for some reason didn't worked value : rec ?
              // rec.get('description') : '',
              anchor : Sonatype.view.FIELDSET_OFFSET
            }
          ],
          buttons : [
            {
              text : 'Ok',
              formBind : true,
              scope : this,
              handler : function() {
                var form = window.find('name', 'publicKeyForm')[0];
                if (!form.getForm().isValid()) {
                  return;
                }

                var id = rec ? rec.get('id') : undefined;

                form.getForm().doAction('sonatypeSubmit', {
                  method : id ? 'PUT' : 'POST',
                  url : Sonatype.config.servicePath + '/smartproxy/trusted-keys' + (id ? '/' + id : ''),
                  fpanel : form,
                  serviceDataObj : {
                    id : '',
                    certificate : '',
                    description : ''
                  },
                  scope : this,
                  success : function() {
                    window.close();
                    this.trustedKeysStore && this.trustedKeysStore.reload();
                  }
                });
              }
            },
            {
              text : 'Cancel',
              formBind : false,
              scope : this,
              handler : function() {
                window.close();
              }
            }
          ]
        }
      ]
    });

    window.show();

    if (rec) {
      // FIXME for some reason value didn't worked
      window.find('name', 'id')[0].setValue(rec.get('id'));
      window.find('name', 'certificate')[0].setValue(rec.get('certificate').pem);
      window.find('name', 'description')[0].setValue(rec.get('description'));
    }

    return window;
  },

  showCertificateDetailWindow : function(detailText) {
    var window = new Ext.Window({
      title : 'Certificate Details',
      closable : true,
      autoWidth : false,
      width : 750,
      autoHeight : true,
      modal : true,
      constrain : true,
      resizable : false,
      draggable : false,
      scope : this,
      items : [
        {
          xtype : 'textarea',
          id : 'sp_cert_details',
          height : 400,
          width : 740,
          readOnly : true,
          anchor : Sonatype.view.FIELDSET_OFFSET,
          listeners : {
            render : function(component) {
              component.getEl().on('click', function() {
                var pos = component.getEl().dom.scrollTop;
                component.selectText();
                setTimeout( function() {component.getEl().dom.scrollTop = pos}, 50 );
              })
            }
          }
        }
      ],
      buttons : [
        {
          text : 'Close',
          scope : this,
          handler : function() {
            window.close();
          }
        }
      ]
    });
    window.show();
    Ext.getCmp('sp_cert_details').setValue(detailText);
  }

}

Sonatype.repoServer.SmartProxySettings = function(config) {
  var config = config || {};

  var defaultConfig = {
    region : 'center',
    width : '100%',
    height : '100%',
    autoScroll : true,
    dataModifiers : {
      load : {
      // 'rootData' : this.loadFingerprint.createDelegate(this)
      },
      trustedKeys : this.updateTrustedKeys.createDelegate(this)
    }
  };



  Ext.apply(this, config, defaultConfig);

  this.trustedKeysRecordConstructor = Ext.data.Record.create([{
        name : 'id'
      }, {
        name : 'certificate'
      }, {
        name : 'description',
        sortType : Ext.data.SortTypes.asUCString
      }]);

  this.trustedKeysReader = new Ext.data.JsonReader({
        root : 'data',
        id : 'id'
      }, this.trustedKeysRecordConstructor);

  this.trustedKeysStore = new Ext.data.Store({
        url : Sonatype.config.servicePath + '/smartproxy/trusted-keys',
        reader : this.trustedKeysReader,
        sortInfo : {
          field : 'description',
          direction : 'ASC'
        },
        autoLoad : true,
        listeners : {
          loadexception : {
            fn : function() {
              this.trustedKeysStore.removeAll();
            },
            scope : this
          }
        }
      });

  this.referenceData = {
    enabled : false,
    host : '',
    port : 0,
    advertiseUri : ''
  };

  var deleteButton = new Ext.Button({
        text : 'Delete',
        cls : 'x-btn-text-icon',
        icon : Sonatype.config.resourcePath + '/images/icons/delete.png',
        disabled : true,
        handler : this.removeSelectedPublicKey,
        scope : this
      });

  var editButton = new Ext.Button({
        text : 'Edit',
        cls : 'x-btn-text-icon',
        icon : Sonatype.config.resourcePath + '/images/icons/page_white_put.png',
        disabled : true,
        handler : this.editSelectedPublicKey,
        scope : this
      });

  this.networkForm = new Ext.FormPanel({
        labelWidth : 100,
        region : 'center',
        layoutConfig : {
          labelSeparator : ''
        },
        items : [{
              xtype : 'fieldset',
              checkboxToggle : false,
              title : 'Network Settings',
              anchor : Sonatype.view.FIELDSET_OFFSET,
              collapsible : false,
              autoHeight : true,
              buttonAlign : 'center',
              items : [{
                    xtype : 'checkbox',
                    fieldLabel : 'Enable Server',
                    name : 'enabled',
                    anchor : Sonatype.view.FIELD_OFFSET
                  }, {
                    xtype : 'textfield',
                    fieldLabel : 'Address',
                    helpText : 'Configures the address which the connector will bind to.  Defaults to 0.0.0.0 to bind to all addresses.',
                    name : 'host',
                    emptyText : '0.0.0.0',
                    anchor : Sonatype.view.FIELD_OFFSET
                  }, {
                    xtype : 'numberfield',
                    fieldLabel : 'Port',
                    helpText : 'Configures the port which the connector which will listen for client connections; A value of \'0\' will use a random port.',
                    name : 'port',
                    validator : function(port) {
                      if ( port >= 0 && port <= 65535 ) {
                        return true;
                      } else {
                        return 'Invalid port number (0 for random, positive and less than or equal to 65535 otherwise)'
                      }
                    },
                    allowNegative : false,
                    allowDecimals : false,
                    emptyText : '0',
                    anchor : Sonatype.view.FIELD_OFFSET
                  }, {
                    xtype : 'textfield',
                    fieldLabel : 'Advertised URI',
                    helpText : 'URI which will be advertised to clients for establishing connections. Defaults to the URI reported by the connector.',
                    name : 'advertiseUri',
                    anchor : Sonatype.view.FIELD_OFFSET,
                    emptyText : ''
                  }, {
                    xtype : 'fieldset',
                    id : 'sp_settings_status_fieldset',
                    checkboxToggle : false,
                    title : 'Status',
                    anchor : Sonatype.view.FIELDSET_OFFSET,
                    collapsible : false,
                    autoHeight : true,
                    layoutConfig : {
                      labelSeparator : ''
                    },
                    items : [{
                      fieldLabel : 'Status',
                      hideLabel : true,
                      name : 'status',
                      anchor : Sonatype.view.FIELDSET_OFFSET,
                      xtype : 'displayfield',
                      width : 700
                    }]
                  }],
              buttons : [{
                    text : 'Save',
                    handler : this.saveNetworkSettings,
                    scope : this
                  }, {
                    handler : this.loadNetworkSettings,
                    scope : this,
                    text : 'Cancel'
                  }]
            }, {
              xtype : 'fieldset',
              checkboxToggle : false,
              title : 'Public Key',
              collapsible : false,
              autoHeight : true,
              layoutConfig : {
                labelSeparator : ''
              },
              anchor : Sonatype.view.FIELDSET_OFFSET,
              items : [{
                    xtype : 'textarea',
                    fieldLabel : 'Certificate',
                    name : 'identity.pem',
                    helpText : 'The public key certificate for this server. Install this on remote Nexus instances to allow this server to access remote\'s Smart Proxy services.',
                    readOnly : true,
                    height : 150,
                    anchor : Sonatype.view.FIELDSET_OFFSET,
                    listeners : {
                      render : function(component) {
                        component.getEl().on('click', function() {
                          var pos = component.getEl().dom.scrollTop;
                          component.selectText();
                          setTimeout( function() {component.getEl().dom.scrollTop = pos}, 50 );
                        });
                      }
                    }
                  }, {
                    fieldLabel : 'Fingerprint',
                    xtype : 'displayfield',
                    name : 'identity.fingerprint',
                    anchor : Sonatype.view.FIELDSET_OFFSET
                  }]
            }]
      })

  this.networkForm.on('actioncomplete',
        function(form, action) {

          var enabled = this.networkForm.getForm().findField('enabled');

          var showStatus = enabled && enabled.getValue();

          if ( showStatus )
          {
            if (action.type == 'sonatypeSubmit') {
              // reload form to get enabled info
              this.loadNetworkSettings();
            }
          }

          var statusFieldSet = Ext.getCmp('sp_settings_status_fieldset');
          statusFieldSet && statusFieldSet.setVisible(showStatus);

        }.createDelegate(this));

  Sonatype.repoServer.SmartProxySettings.superclass.constructor.call(this, {
        trackResetOnLoad : true,
        border : false,
        frame : true,
        // scrolling is not enabled correctly, so we have to force the CSS style
        bodyStyle : 'overflow: auto',
        labelWidth : 150,
        layoutConfig : {
          labelSeparator : ''
        },
        items : [this.networkForm, new Ext.FormPanel({
          labelWidth : 100,
          region : 'center',
          layoutConfig : {
            labelSeparator : ''
          },
          items : [{
              xtype : 'fieldset',
              checkboxToggle : false,
              title : 'Trusted Certificates',
              anchor : Sonatype.view.FIELDSET_OFFSET,
              autoHeight : true,
              collapsible : false,
              layoutConfig : {
                labelSeparator : ''
              },
              items : [{
                    xtype : 'grid',
                    name : 'trustedKeys',
                    helpText : 'The public key certificates which have been installed on this server. Remote Nexus instances in this list can access Smart Proxy services.',
                    anchor : Sonatype.view.FIELD_OFFSET,
                    ds : this.trustedKeysStore,
                    height : 250,
                    viewConfig : {
                      forceFit : true
                    },
                    listeners : {
                      'celldblclick' : {
                        fn : function(grid, rowIdx, columnIdx, evt) {
                          this.editSelectedPublicKey();
                        },
                        scope : this
                      }
                    },
                    sm : new Ext.grid.RowSelectionModel({
                          singleSelect : true,
                          listeners : {
                            rowselect : function() {
                              editButton.enable();
                              deleteButton.enable();
                            },
                            rowdeselect : function() {
                              editButton.disable();
                              deleteButton.disable();
                            },
                            scope : this
                          }

                        }),
                    columns : [{
                          id : 'certificate',
                          header : "Fingerprint",
                          sortable : true,
                          dataIndex : 'certificate',
                          renderer : this.fingerprintRenderer
                        }, {
                          id : 'description',
                          header : "Description",
                          width : 300,
                          sortable : true,
                          dataIndex : 'description'
                        }]
                  }],
              tbar : [
                  {
                    text : 'Refresh',
                    cls : 'x-btn-text-icon',
                    icon : Sonatype.config.resourcePath + '/images/icons/arrow_refresh.png',
                    handler : this.refreshKeys,
                    scope : this
                  }, {
                    text : 'Add',
                    cls : 'x-btn-text-icon',
                    icon : Sonatype.config.resourcePath + '/images/icons/add.png',
                    handler : function() {
                      this.showAddCertificateWindow('Add Trusted Certificate', undefined);
                    },
                    scope : this
                  },
                  editButton,
                  deleteButton
              ]}
          ]}
        )]
      });

  this.on('afterlayout', this.loadNetworkSettings, this, {
        single : true
      });

};

Ext.extend(Sonatype.repoServer.SmartProxySettings, Ext.Panel, Ext.applyIf({
      loadNetworkSettings : function() {
        this.networkForm.getForm().doAction('sonatypeLoad', {
              fpanel : this.networkForm,
              method : 'GET',
              scope : this,
              url : Sonatype.config.servicePath + '/smartproxy/settings'
            });
      },
      saveNetworkSettings : function() {
        this.networkForm.getForm().doAction('sonatypeSubmit', {
              method : 'PUT',
              fpanel : this.networkForm,
              serviceDataObj : this.referenceData,
              scope : this,
              waitMsg : 'Saving network settings...',
              dataModifiers : {
                  port : function(value) { return value ? value : 0; }
              },
              url : Sonatype.config.servicePath + '/smartproxy/settings'
            });
      },

      fingerprintRenderer : function(value, metaData, record, rowIndex, colIndex, store) {
        return value.fingerprint;
      },

      refreshKeys : function() {
        this.trustedKeysStore.reload();
      },

      removeSelectedPublicKey : function() {
        var sm = this.find('name', 'trustedKeys')[0].getSelectionModel();
        var rec = sm.getSelected();

        Sonatype.MessageBox.show({
              title : 'Delete Certificate?',
              msg : 'Delete trusted certificate \'' + rec.get('description') + '\'?',
              buttons : Sonatype.MessageBox.YESNO,
              scope : this,
              icon : Sonatype.MessageBox.QUESTION,
              fn : function(btnName) {
                if ( btnName === 'yes' )
                {
                  Ext.Ajax.request({
                        url : Sonatype.config.servicePath + '/smartproxy/trusted-keys/' + rec.get('id'),
                        method : 'DELETE',
                        callback : function() {
                          sm.clearSelections();
                          this.trustedKeysStore.remove(rec);
                        },
                        scope : this
                      });
                }
              }
            });
      },

      editSelectedPublicKey : function() {
        var rec = this.find('name', 'trustedKeys')[0].getSelectionModel().getSelected();

        this.showAddCertificateWindow('Trusted Certificate', rec);
      },


      updateTrustedKeys : function(val, panel) {
        var data = [];

        var items = this.trustedKeysStore.data.items;
        for (var i = 0; i < items.length; i++)
        {
          data.push(items[i].data);
        }
        return data;
      }

    }, Sonatype.repoServer.SmartProxyCertificateUtils));

Sonatype.Events.addListener('nexusNavigationInit', function(nexusPanel) {
  if (Sonatype.lib.Permissions.checkPermission('nexus:smartproxy:settings', Sonatype.lib.Permissions.READ)) {
    nexusPanel.add({
      enabled : true,
      sectionId : 'st-nexus-enterprise',
      title : 'Smart Proxy',
      tabId : 'smart_proxy',
      tabTitle : 'Smart Proxy',
      tabCode : Sonatype.repoServer.SmartProxySettings
    });
  }
});

//
// Repository Tab Panel
//

Sonatype.Events.addListener('repositoryViewInit', function(cardPanel, rec) {
      var sp = Sonatype.lib.Permissions;
      if (sp.checkPermission('nexus:smartproxy:pub-sub', sp.READ) &&
            rec.data.id  // not a new repo
            )
      {
        cardPanel.add(new Sonatype.repoServer.SmartProxyPanel({
              name : 'smartproxy',
              tabTitle : 'Smart Proxy',
              repoType : rec.data.repoType,
              payload : {
                id : rec.data.id,
                data : {
                  publish : false,
                  subscribe : false,
                  preemptiveFetch : false,
                  repositoryId : rec.data.id,
                  resourceURI : Sonatype.config.servicePath + '/smartproxy/pub-sub/' + rec.data.id
                }
              }
            }));
      }
    });

Sonatype.repoServer.SmartProxyPanel = function(config) {
  var config = config || {};

  this.referenceData = {
    publish : false,
    subscribe : false,
    preemptiveFetch : false
  };

  var defaultConfig = {
    dataModifiers : {
      load : {},
      submit : {}
    }
  };

  Ext.apply(this, config, defaultConfig);

  this.downloadUpdatedArtifactsStore = new Ext.data.SimpleStore({
        fields : ['value', 'display'],
        data : [[false, 'Upon Request'], [true, 'Immediately']]
      });

  Sonatype.repoServer.SmartProxyPanel.superclass.constructor.call(this, {
        region : 'center',
        trackResetOnLoad : true,
        autoScroll : true,
        border : false,
        frame : true,
        collapsible : false,
        collapsed : false,
        layoutConfig : {
          labelSeparator : ''
        },
        labelWidth : 225,
        width : 900,
        items : [{
              xtype : 'fieldset',
              checkboxToggle : false,
              title : 'Publish',
              anchor : Sonatype.view.FIELDSET_OFFSET,
              collapsible : false,
              autoHeight : true,
              layoutConfig : {
                labelSeparator : ''
              },
              items : [{
                xtype : 'checkbox',
                fieldLabel : 'Publish Updates',
                checked : false,
                name : 'publish',
                helpText : 'Inform downstream Nexus instances when items have been created or updated.'
              }, {
                xtype : 'fieldset',
                id : 'sp_publish_status_fieldset',
                checkboxToggle : false,
                title : 'Status',
                anchor : Sonatype.view.FIELDSET_OFFSET,
                collapsible : false,
                autoHeight : true,
                layoutConfig : {
                  labelSeparator : ''
                },
                items : [{
                  xtype : 'displayfield',
                  fieldLabel : 'Status',
                  hideLabel : true,
                  name : 'publishStatus',
                  anchor : Sonatype.view.FIELDSET_OFFSET,
                  width : 700
                }]
              }]
        }, {
              xtype : 'fieldset',
              checkboxToggle : false,
              title : 'Subscribe',
              anchor : Sonatype.view.FIELDSET_OFFSET,
              collapsible : false,
              autoHeight : true,
              /* subscription only for proxy repos */
              hidden: config.repoType !== 'proxy',
              layoutConfig : {
                labelSeparator : ''
              },
              items : [{
                    xtype : 'checkbox',
                    fieldLabel : 'Receive Updates',
                    checked : false,
                    name : 'subscribe',
                    helpText : 'Clear the local cache associated with remote items when they are created or updated.'
                  }, {
                    xtype : 'combo',
                    lazyInit : false,
                    fieldLabel : 'Download Updated Artifacts',
                    itemCls : 'required-field',
                    helpText : 'Download policy for update events: Upon Request - when requested from local Nexus, Immediately - as soon as notification is received.',
                    name : 'preemptiveFetch',
                    store : this.downloadUpdatedArtifactsStore,
                    valueField : 'value',
                    displayField : 'display',
                    editable : false,
                    forceSelection : true,
                    mode : 'local',
                    triggerAction : 'all',
                    selectOnFocus : true,
                    emptyText : 'Select...',
                    allowBlank : false,
                    value : 'pom',
                    minListWidth : 100
                  }, {
                    xtype : 'displayfield',
                    fieldLabel : 'Remote Fingerprint',
                    name : 'certificate.fingerprint',
                    style : 'text-decoration: underline; color: blue; cursor: pointer;',
                    listeners : {
                      render : {
                        fn : function(component) {
                          component.getEl().on('click', this.showCertificate.createDelegate(this));
                        },
                        scope: this
                      }
                    }
                  }, {
                    xtype : 'fieldset',
                    id : 'sp_subscribe_status_fieldset',
                    checkboxToggle : false,
                    title : 'Status',
                    anchor : Sonatype.view.FIELDSET_OFFSET,
                    collapsible : false,
                    autoHeight : true,
                    layoutConfig : {
                      labelSeparator : ''
                    },
                    items : [{
                      xtype : 'displayfield',
                      fieldLabel : 'Status',
                      hideLabel : true,
                      name : 'subscriptionStatus',
                      anchor : Sonatype.view.FIELDSET_OFFSET,
                      width : 700
                    }],
                    listeners : {
                      show: {
                        fn : function(component) {
                          var cmp = Ext.get('sp_remote_cert_' + this.payload.id);
                          cmp && cmp.on('click',
                                this.showCertificate.createDelegate(this));
                        },
                        scope: this
                      }
                  }
                }, { // TODO should use a store to avoid defining these hidden fields
                  xtype : 'textarea',
                  name : 'certificate.pem',
                  hideLabel : true,
                  hidden : true
                }, {
                  xtype : 'textarea',
                  name : 'certificate.detail',
                  hideLabel : true,
                  hidden : true
            }]
      }]
  });

  this.on('actioncomplete', function(form, action) {
    if (action.type == 'sonatypeSubmit') {
      // reload form to get status info
      this.loadData();
    }

    var publishEnabledField = form.findField('publish');
    var publishEnabled = publishEnabledField && publishEnabledField.getValue();
    var publishStatusFieldSet = Ext.getCmp('sp_publish_status_fieldset');
    var publishStatusField = form.findField('publishStatus');
    publishStatusFieldSet && publishStatusFieldSet.setVisible(publishEnabled && publishStatusField.getValue());

    var subscriptionEnabledField = form.findField('subscribe');
    var subscriptionEnabled = subscriptionEnabledField && subscriptionEnabledField.getValue();
    var subscribeStatusFieldSet = Ext.getCmp('sp_subscribe_status_fieldset');
    var subscriptionStatusField = form.findField('subscriptionStatus');
    subscribeStatusFieldSet && subscribeStatusFieldSet.setVisible(subscriptionEnabled && subscriptionStatusField.getValue());

    var fpField = form.findField('certificate.fingerprint');
    fpField && fpField.setVisible(subscriptionEnabled && fpField.getValue());

  }.createDelegate(this));
};

Ext.extend(Sonatype.repoServer.SmartProxyPanel, Sonatype.ext.FormPanel, Ext.apply(Sonatype.repoServer.SmartProxyCertificateUtils, {
  showWindow : function(record) {
    var window = this.showAddCertificateWindow('Add Trusted Certificate', record);
    window.find('name', 'certificate')[0].disable();

    setTimeout(function() {
      var description = window.find('name', 'description')[0];
      if ( description )
      {
        description.focus();
        description.clearInvalid();
      }
    }, 200);
  },
  showCertificate : function(element) {
    var fingerprint = this.getForm().findField('certificate.fingerprint').getValue();

    Ext.Ajax.request({
      url : Sonatype.config.servicePath + '/smartproxy/trusted-keys',
      method : 'PUT',
      jsonData : {
        data : {
          // FIXME use real response object once this request has a different URL
          id : fingerprint
        }
      },
      success : function(resp) {
        var record = new Ext.data.Record(Ext.decode(resp.responseText).data);
        this.showWindow(record);
      },
      failure : function(resp) {
        if ( resp.status == 404 ) {
          Sonatype.MessageBox.hide();
          var pem = this.getForm().findField('certificate.pem').getValue();
          var detail = this.getForm().findField('certificate.detail').getValue();
          var record = new Ext.data.Record({
            certificate : {
              pem : pem,
              detail : detail
            }
          });
          this.showWindow(record);
        } else if ( resp.status == 400 ) {
          Sonatype.MessageBox.hide();
          var msg = Ext.decode(resp.responseText).validationErrors[0].message;
          Sonatype.MessageBox.show({
            title : 'Trust Capability Error',
            msg : msg,
            buttons : Sonatype.MessageBox.OK,
            icon : Sonatype.MessageBox.ERROR
          });

          var cmp = Ext.get('sp_goto_capabilities');
          cmp && cmp.on('click',
                function(element) {
                  Sonatype.MessageBox.hide();
                }
          );
        }
      },
      scope : this
    });
  }
}));



