/*
 * Copyright (c) 2008-2012 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */

/*global $,console,Nexus*/
$(document).ready(function() {
  "use strict";

  var
        query = {},
        activationUrl = $('#activation-url').attr('href'),
        iframeLoaded = false,
        // objects
        iframeContainer = $('#iframe-container'),
        iframe = iframeContainer.find('iframe'),
        inputFile,
        // functions
        invalid, clearInvalid, showError, mask, unmask, showAgreementWindow, uploadB64;

  Nexus.init(iframe[0].contentWindow);

  Nexus.on('page-load', function() {
    iframeLoaded = true;
    $('#iframe-container').unmask();
    $('#iframe-container iframe').show();
    $('#local-page').hide();
  });

  Nexus.on('install', function(id, payload) {
    showAgreementWindow(uploadB64, payload);
  } );

  Nexus.on('location', function(id, payload) {
    window.location = payload;
  });

  Nexus.on('nexus-status', function(){
    $.ajax('../service/local/status', {
      type : 'GET',
      headers : {
        'Accept' : 'application/json'
      },
      success : function(data, status, xhr) {
        delete data.permissions;
        Nexus.send('nexus-status', data);
      },
      error : function(xhr, status, error) {
        try {
          Nexus.send('nexus-status', xhr.responseText);
        } catch(e) {
          Nexus.send('nexus-status', undefined);
        }
      }
    });
  });

  /** iframe setup **/
  $(window).bind("load resize", function() {
    iframeContainer.height($(window).height()-150);
  });

  iframeContainer.mask('Loading license activation page...');

  /**
   * Show local activation page when iframe is not loaded.
   */
  window.setTimeout( function() {
          if ( !iframeLoaded ) {
            $('#iframe-container iframe').hide();
            $('#iframe-container').unmask();
            $('#switch-page').css('visibility', 'hidden');
            if ( !($('#local-page').is(':visible')) ) {
              $('#local-page').show();
              invalid('Nexus could not connect to the license activation service. Please paste your full license or upload a license file.');
            }
          }
        },
        10000);

  /** UI setup **/
  invalid = function(msg) {
    $('#error')[0].innerHTML = msg;
  };
  clearInvalid = function() {
    invalid('');
  };

  showError = function(data) {
    var msg, id;

    if (data.errors) {
      msg = data.errors[0].msg;
      id = data.errors[0].id;

      if (id) {
          invalid(msg);
          Nexus.error(id, msg);
      } else {
          invalid(data.errors);
        // TODO this may break on receiver when data.errors contains invalid chars for json string
          Nexus.error('raw', data.errors);
      }
    } else {
      msg = 'Could not activate the license. Check the Nexus logs for further information or <a target="_blank" href="http://links.sonatype.com/products/nexus/pro-eval/support-request">contact us</a>.';
      invalid(msg);
      Nexus.error('unknown', msg);
    }

    // signal whether we actually had an error
    return data.errors !== undefined;
  };

  mask = function(msg) {
    if ( $('#local-page').is(':visible') ) {
      $('body').mask(msg);
    }
  };
  unmask = function() {
    $('body').unmask();
  };

  /** license installation setup **/
  showAgreementWindow = function(agreeFn, arg) {
    var agreementWindow = $('#license-agreement');
    agreementWindow.find('.content').load('../LICENSE.html');
    agreementWindow.dialog({
      title : 'Nexus Professional License Agreement',
      width : 600,
      height : 500,
      modal : true,
      show : function() {
        // remove css classes from buttons to have the default style
        var buttons = $(this).find('.ui-button');
        buttons.unbind('mouseenter mouseleave mousedown focus');
        buttons[0].className = 'download-license-button';
        buttons[1].className = 'dialog-button';
        buttons[2].className = 'dialog-button';
        $(this).focus();
      },
      buttons : {
        'Download a copy of the license.' : function(evt) {
          window.open('../LICENSE.html', '_new');
        },
        'I Agree' : function(evt) {
          agreementWindow.dialog('close');
          agreementWindow.dialog('destroy');
          agreeFn(arg);
        },
        'I Don\'t Agree' : function(evt) {
          agreementWindow.dialog('close');
          agreementWindow.dialog('destroy');
          Nexus.error('eula', 'The license agreement has to be accepted in order to install a license.');
        }
      }
    });

    // content is at the bottom after first dialog view, so scroll to top explicitely
    $('#license-agreement').scrollTop(0);
  };

  /* Upload Controllers */
  uploadB64 = function(b64) {
    mask('Activating license...');
    $.ajax('../service/local/licensing/upload', {
      type : 'POST',
      cache : false,
      contentType : 'text/plain',
      data : b64,
      headers : {
        'Accept' : 'application/json'
      },
      success : function(data, textStatus, xhr) {
        if ( !iframeLoaded) {
          window.location = '../index.html';
        } else {
          Nexus.send('license-installed');
        }
      },
      error : function(xhr, status, error) {
        if (!xhr.responseText || !showError(JSON.parse(xhr.responseText))) {
          if (error) {
            // in this case we have more info here than the generic error message shown by showError()
            invalid('Could not activate the license: ' + error);
          }
        }
      },
      complete : function() {
        unmask();
      }
    });
  };

  $('#switch-page').click(function() {
    var local = $('#local-page');

    if ( iframeLoaded && local.is(':visible') ) {
      local.hide();
      $(iframe).show();
      $(this).text('Already have a license file?');
    } else {
      local.show();
      $(iframe).hide();
      iframeContainer.unmask();
      $(this).text('Already have a license id?');
    }
  });

  /**
   * Set up file upload method.
   */
  $(function() {
    var oldBrowser = !($.support.xhrFormDataFileUpload);

    $('input[name=file]').fileupload({
      dataType : 'json',
      // by default, the plugin replaces the input element to work with multi file uploads with iframes,
      // but then user has no visual clue about selected file (b/c the new element is empty)
      replaceFileInput : false,
      // change URL for IE/old browser upload to switch behavior in the REST resource
      url : "../service/local/licensing/upload" + (oldBrowser?"/ie":""),
      add : function(e, data) {
        inputFile = data;
        return true;
      },
      fail : function(e, data) {
        unmask();
        var json = $.parseJSON(data.jqXHR.responseText);
        showError(json||{});
      },
      done : function(e, data) {
        unmask();

        var json = data.result;

        // we may get here for iframe transport + certain error codes as well
        // IE will treat at least 400 and 500 status as CORS (because it loads a local error page)
        // and will get here without any response object
        if ( !json || !json.success ) {
          showError(json||{});
          return;
        }

        window.location = '../index.html';
      }
    });
  });

  /**
   * License installation with BASE64 content.
   */
  $('#activate').click(function(evt) {
    var
          // objects
          urlPath = '/rest/license/',
          fp = $.trim($('#localLicense').val());

    clearInvalid();
    if (fp.length === 0 && inputFile === undefined) {
      invalid('Please paste your license or choose a license file to upload.');
    } else if (fp.length === 40) {
      invalid('Nexus could not connect to the license activation service. Please paste your full license or upload a license file.');
    } else if (fp.length > 40) {
      showAgreementWindow(uploadB64, fp);
    } else if ( inputFile !== undefined ) {
        showAgreementWindow(function() {
          mask("Uploading License...");
          inputFile.submit();
        });
    } else {
      invalid('This does not appear to be a valid license key. If you continue to experience problems activating your license, please <a target="_blank" href="http://links.sonatype.com/products/nexus/pro-eval/support-request">contact us</a>.');
    }
  });

  // append type and version to external URL
  query.t = $.trim($('#bundle-type').text());
  query.v = $.trim($('#nexus-version').text());

  // setting iframe.src last to have everything else in place before.
  iframe[0].src = activationUrl + '?t=' + query.t + '&v=' + query.v;
});
